[−][src]Enum uom::str::ParseQuantityError
Represents an error encountered while parsing a string into a Quantity.
Variants
No separators (spaces) were encountered.
An error occurred while parsing the value (first) portion of the string.
Due to exhaustiveness and type system limitations, this variant does not encode the underlying parse error.
The unit used wasn't found for this quantity.
Notes
For now, only abbreviations are supported, so this error may be encountered even if the unit name (description) is correct.